Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3929)

Unified Diff: chrome/browser/ui/passwords/manage_passwords_state.cc

Issue 1723583004: CREDENTIAL: Convert federations from URLs to origins throughout. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: iOS2 Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/passwords/manage_passwords_state.cc
diff --git a/chrome/browser/ui/passwords/manage_passwords_state.cc b/chrome/browser/ui/passwords/manage_passwords_state.cc
index 6d4508cca9fd07e4c65508b76e16e86bc274a4a3..dc8657d9ad4ddd24ad3a43549f21dbb4b9f5878b 100644
--- a/chrome/browser/ui/passwords/manage_passwords_state.cc
+++ b/chrome/browser/ui/passwords/manage_passwords_state.cc
@@ -229,14 +229,14 @@ void ManagePasswordsState::ChooseCredential(
// cross-origin.
//
// If |credential_type| is local, the credential MIGHT be a PasswordCredential
// or it MIGHT be a FederatedCredential. We inspect the |federation_url|
// field to determine which we should return.
//
// TODO(mkwst): Clean this up. It is confusing.
password_manager::CredentialType type_to_return;
if (credential_type ==
password_manager::CredentialType::CREDENTIAL_TYPE_PASSWORD &&
- form.federation_url.is_empty()) {
+ form.federation_origin.unique()) {
type_to_return = password_manager::CredentialType::CREDENTIAL_TYPE_PASSWORD;
} else if (credential_type ==
password_manager::CredentialType::CREDENTIAL_TYPE_EMPTY) {
@@ -229,14 +229,14 @@ void ManagePasswordsState::ChooseCredential(
//
// If |credential_type| is local, the credential MIGHT be a PasswordCredential
- // or it MIGHT be a FederatedCredential. We inspect the |federation_url|
+ // or it MIGHT be a FederatedCredential. We inspect the |federation_origin|
// field to determine which we should return.
//

Powered by Google App Engine
This is Rietveld 408576698